@@ -15,17 +15,28 @@ def find_extensions(name, setup_py):
     return [Extension(*x) for x in ex]
 
 
-class build_py(build_py_orig):
-    def build_packages(self):
-        pass
+def build_py(setup_py):
+    class BuildPy(build_py_orig):
+
+        def build_packages(self):
+            if os.environ.get('NO_CLEAR_ARTIPY') == "1":
+                return
+            else:
+                dirname = os.path.split(setup_py)[0]
+                os.remove(os.path.join(dirname, "build"))
+                for root, subdirs, files in os.walk(dirname):
+                    for fname in os.listdir(root):
+                        fname.endswith('.c')
+                        os.remove(fname)
+
+    return BuildPy
 
 
-def artipy(dirname, setup_py, include_package_data=False):
+def artipy(dirname, setup_py):
     if os.environ.get('DISABLE_ARTIPY') == "1":
         return {}
     else:
         return {
-            'include_package_data': include_package_data,
             'ext_modules': cythonize(find_extensions(dirname, setup_py)),
-            'cmdclass': {'build_py': build_py},
+            'cmdclass': {'build_py': build_py(setup_py)},
         }
